BEGIN
  FOR k IN (SELECT null FROM all_synonyms WHERE owner = 'PUBLIC' and synonym_name = 'SPERMISSION_V') LOOP
    EXECUTE IMMEDIATE 'DROP PUBLIC SYNONYM SPERMISSION_V';
  END LOOP;
  FOR i IN (SELECT null FROM all_views WHERE owner = user and view_name = 'SPERMISSION_V') LOOP
    EXECUTE IMMEDIATE 'DROP VIEW SPERMISSION_V';
  END LOOP;
  FOR k IN (SELECT null FROM all_synonyms WHERE owner = 'PUBLIC' and synonym_name = 'SUSER_ACCOUNT_PERMISSION_V') LOOP
    EXECUTE IMMEDIATE 'DROP PUBLIC SYNONYM SUSER_ACCOUNT_PERMISSION_V';
  END LOOP;
  FOR i IN (SELECT null FROM all_views WHERE owner = user and view_name = 'SUSER_ACCOUNT_PERMISSION_V') LOOP
    EXECUTE IMMEDIATE 'DROP VIEW SUSER_ACCOUNT_PERMISSION_V';
  END LOOP;
END;
/

CREATE VIEW spermission_v AS
  SELECT 
        spermission.id,
        spermission.account_grant,
        spermission.assignable,
        spermission.authoritative,
        spermission.bound_by_id,
        spermission.boundable,
        spermission.cost,
        spermission.deleted,
        spermission.description,
        spermission.display_name,
        spermission.driver_id,
        spermission.effective,
        spermission.exclude_from_catalog,
        spermission.is_curated,
        spermission.logical_id,
        spermission.merged,
        spermission.name,
        spermission.not_reviewable,
        spermission.permission_id,
        spermission.prov_attribute,
        spermission.prov_by_unique_permission_id,
        spermission.prov_native_value,
        spermission.prov_unique_driver_id,
        spermission.provisionable,
        spermission.risk,
        spermission.type,
        spermission.unique_bound_by_id,
        spermission.unique_permission_id,
        spermission.value,
        spermission.value_type,
        spermission.application,
        spermission.base_application,
        spermission.collected_entity,
        spermission.data_collection,
        spermission.effective_entity,
        spermission.sversion,
        spermission.auto_generated,
        spermission.prov_unique_permission_id,
        perm_owner.perm_owner_name
FROM 
        spermission
        LEFT JOIN (SELECT rso.permission,
                LISTAGG(TO_CHAR(suser.display_name), ' | ') WITHIN GROUP (ORDER BY suser.display_name) perm_owner_name
                FROM (SELECT DISTINCT owner_unique_id, permission
                  FROM resolved_spermission_owner) rso
                  JOIN suser ON suser.unique_user_id = rso.owner_unique_id AND suser.deleted = 0 AND suser.effective = 1
          GROUP BY rso.permission) perm_owner ON perm_owner.permission = spermission.id
WHERE 
        (exclude_from_catalog = 0 OR exclude_from_catalog IS NULL) AND effective = 1;

CREATE VIEW suser_account_permission_v AS
  select
        case when sap.id is not null then
            sau.id || '.' || sap.id
        else
            sau.id || '.null'
        end as id,
        su.id as suser,
        su.collected_entity as collected_entity,
        sa.id as saccount,
        sp.id as spermission,
        sau.sversion as sversion,
        sau.id as saccount_user,
        sap.id as saccount_permission,
        sap.value as spermission_value,
        case when (sa.virtual is null or sa.virtual = 0) then
            sau.id
        else
            null
        end as real_saccount_user
    from saccount_user sau
    join saccount sa on sa.collected_entity = sau.saccount and sa.effective = 1 and sa.deleted = 0
    join suser su on su.collected_entity = sau.suser and su.effective = 1 and su.deleted = 0
    left join saccount_permission sap on sap.saccount = sau.saccount and sap.effective = 1
    left join spermission sp on sp.collected_entity = sap.spermission and sp.effective = 1 and sp.deleted = 0
    where
      sau.effective = 1;


GRANT SELECT ON igops.spermission_v TO ig_report_role;
CREATE PUBLIC SYNONYM spermission_v FOR igops.spermission_v;

GRANT SELECT ON igops.suser_account_permission_v TO ig_report_role;
CREATE PUBLIC SYNONYM suser_account_permission_v FOR igops.suser_account_permission_v;


